import { createApp, Component, getCurrentInstance } from "vue";

export const useUnmountComponent = () => {
	const instance = getCurrentInstance();
	const unmountComponent = () => {
		instance?.appContext.app.unmount();
		document.body.removeChild(instance?.appContext.app._container);
	};

	return {
		unmountComponent,
	};
};

export function mountComponent(RootComponent: Component, rootProps?: Record<string, unknown> | null | undefined) {
	const app = createApp(RootComponent, rootProps);
	const root = document.createElement("div");

	document.body.appendChild(root);

	return {
		instance: app.mount(root),
		unmount() {
			app.unmount();
			document.body.removeChild(root);
		},
	};
}
